conoha
    * ``auth_region`` Specify region. if empty, region 'tyo1' will be used.

    * ``auth_token`` Specify token for authentication. if empty, the username and password will be used to create a token.

    * ``auth_username`` Specify api username for authentication. only used if --auth-token is empty.

    * ``auth_password`` Specify api user password for authentication. only used if --auth-token is empty.

    * ``auth_tenant_id`` Specify tenand id for authentication. only used if --auth-token is empty.
